# Using the start, test and loop commands (cszp_soccer.py)

note: This wiki is based on cszp 4.5.0 or later.

In this article, I'm going to explain how to use the start, test, and loop commands in cszp.  
Because cszp is an interactive execution system, you can execute cszp very easily just by answering a question. Let's see how it works!

## 1. Confirmation of settings (common to all commands)
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage1.png)

The first thing to do is to check the settings. Make sure you have everything set up correctly. If there is a problem, select CANCEL and go back to the menu screen to reconfigure.  
You can use the arrow keys, the Tab and Space keys to select it, and the mouse click.

## 2. Team1 (yellow) Select the path for your team (common to all commands).
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage2.png)

Next, select the path for the yellow team in Team 1.  
If you have registered a player in the cszp Simple Soccer Execution List (see below), select Yes to proceed to 3.  
If you don't have a player registered, select No and go to 3.5.  
If you want to change the name, click on the "Cancel" button to return to the previous screen.  
The choice is the same as before.

## 3. Select from the Easy Soccer Execution List

Hint: If you see something like this, the player is not set in the list, please press Ok and select the program you want to run from the file or press Cancel and re-set it![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage3.png)

![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage4.png)

You can use the spacebar to select it. Once done, press Tab to select Ok. The mouse will respond to this part.

## 3.5. Select from file.

Hint: If you get a screen like this, please increase the size of the screen or reduce the font size, because the screen is small![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage5.png)

![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage6.png)

Use the arrow keys to select the file. Note that you cannot use the mouse on this screen; press the q key to change or re-set the selection method. You can also use the F4 key or Ctrl+F or Command+F to search for a file.

## 4.Team2 (red) Select the path of the team (common to all commands).

Use the same way as the yellow team's setup.

## 5. Enter server arguments (common to each command).
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage7.png)

Enter the server argument. If not, select Ok in the field. If you don't, select Ok in the blank. Also, it's ok to enter arguments for the synch mode, because they are automatically entered.

## 6. various settings (common to each command).
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage8.png)
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage9.png)
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage10.png)
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage11.png)

Various settings. Select as necessary.

## 7.csv file name (common to each command, only in csv log saving mode).
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage12.png)

This screen is displayed only when you set Yes to save the csv log. Please specify the name to be saved.

## 8. specify the number of times to loop (only when executing the loop command).
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage13.png)

This message is displayed only when executing the loop command. Please set the loop count in half-width characters.

## 9. confirmation (common to each command)
![](https://kumitatepazuru.github.io/cszp/jp/usage2/usage14.png)

Last check. Make sure everything is OK. If everything is OK, choose Yes.

## 10. execute (common to all commands).

Hint: If you get a screen like this, something is wrong with the program or the path is wrong. Please check it out![](usage2/usage15.png)
Execution. When it finishes successfully without error, press Enter to return to the home screen.

Now you know how to use the start, test, and loop commands. Next, I'm going to introduce the setting screen. Okay then!